pub struct AddStaffCmd {
pub part_index: usize,
pub clef: Clef,
}Expand description
Add a new staff to an existing part with the given clef.
The new staff is appended with empty measures matching the current measure count.
Clef values: "Treble" | "Bass" | "Alto" | "Tenor" | "Percussion".
Fields
part_index: usizeclef: ClefTrait Implementations
Sourceimpl Clone for AddStaffCmd
impl Clone for AddStaffCmd
Sourcefn clone(&self) -> AddStaffCmd
fn clone(&self) -> AddStaffCmd
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddStaffCmd
impl Debug for AddStaffCmd
Sourceimpl<'de> Deserialize<'de> for AddStaffCmd
impl<'de> Deserialize<'de> for AddStaffCmd
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more