pub struct PasteRangeCmd {
pub part_index: usize,
pub staff_index: usize,
pub voice_index: usize,
pub target_measure: usize,
pub measures: Vec<Vec<Note>>,
}Expand description
Replace a contiguous range of voice measures with stored notes (undo-able).
measures contains one Vec<Note> per measure to paste, starting at target_measure.
The target voice of each measure is replaced entirely.
Fields
part_index: usizestaff_index: usizevoice_index: usizetarget_measure: usizemeasures: Vec<Vec<Note>>One note list per measure, in order.