pub struct SetSystemBreakIntervalCmd {
pub interval: u32,
pub start_measure: Option<usize>,
pub end_measure: Option<usize>,
}Expand description
Replace system (line) breaks with one after every interval measures, or remove them when
interval is 0 (MuseScore’s “Add/remove line breaks”). Page and section breaks are kept, and
no break is added after the final measure of the score.
Fields
interval: u32start_measure: Option<usize>Inclusive physical measure index; defaults to the first measure.
end_measure: Option<usize>Exclusive physical measure index; defaults to the measure count.