pub struct CrossStaff {
pub target_staff: usize,
pub target_voice: Option<usize>,
}Expand description
Cross-staff placement metadata. The note remains in its source staff, so its stable playback address continues to identify the original note.
Fields
target_staff: usizetarget_voice: Option<usize>Trait Implementations
Sourceimpl Clone for CrossStaff
impl Clone for CrossStaff
Sourcefn clone(&self) -> CrossStaff
fn clone(&self) -> CrossStaff
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CrossStaff
impl Debug for CrossStaff
Sourceimpl<'de> Deserialize<'de> for CrossStaff
impl<'de> Deserialize<'de> for CrossStaff
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CrossStaff
Sourceimpl PartialEq for CrossStaff
impl PartialEq for CrossStaff
Sourceimpl Serialize for CrossStaff
impl Serialize for CrossStaff
impl StructuralPartialEq for CrossStaff