pub struct TablaturePerformanceEvent {
pub playback: PlaybackEvent,
pub string: u8,
pub fret: u8,
pub technique: Option<GuitarTechnique>,
pub bend_alter_cents: Option<i16>,
pub bend_curve: Vec<GuitarBendPoint>,
pub expected_pitch_midi_cents: i32,
pub pitch_error_cents: i32,
}Fields
playback: PlaybackEventstring: u8fret: u8technique: Option<GuitarTechnique>Authored guitar technique for the host playback adapter, when present.
bend_alter_cents: Option<i16>Authored bend alteration in cents, when the technique is Bend.
bend_curve: Vec<GuitarBendPoint>Normalized bend/hold/release curve for a bend-capable host. Positions are per-mille of this event’s sounding duration and values are cents relative to the written pitch.
expected_pitch_midi_cents: i32pitch_error_cents: i32Trait Implementations
Sourceimpl Clone for TablaturePerformanceEvent
impl Clone for TablaturePerformanceEvent
Sourceimpl Debug for TablaturePerformanceEvent
impl Debug for TablaturePerformanceEvent
Sourceimpl<'de> Deserialize<'de> for TablaturePerformanceEvent
impl<'de> Deserialize<'de> for TablaturePerformanceEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for TablaturePerformanceEvent