diff

Function diff 

pub fn diff(a: &Score, b: &Score) -> Vec<ScoreChange>
Compare two scores and return a list of differences.

Parts, staves, measures, and voices are compared by position. Notes are compared by position within each voice, ignoring their id field. Metadata fields are compared individually.