pub struct PartGroup {
pub first_part: usize,
pub last_part: usize,
pub symbol: PartGroupSymbol,
pub barlines_connect: bool,
}Expand description
Groups a range of adjacent parts with a bracket or brace for rendering.
Fields
first_part: usizeIndex of the first part in the group (inclusive).
last_part: usizeIndex of the last part in the group (inclusive).
symbol: PartGroupSymbolbarlines_connect: boolWhether barlines are connected across all staves in the group.